@@ -735,6 +735,16 @@ class Client(Callbacks, SocketHandler):
         if response.status_code != 200: return exceptions.CheckException(json.loads(response.text))
         else: return response.status_code
 
+    def random_community(self,search:str,start: int = 0, size: int = 25):
+        response=requests.get(f"{self.api}/g/s/community/search?q={search}&language=en&completeKeyword=1&start={start}&size={size}",headers=self.parse_headers(), proxies=self.proxies, verify=self.certificatePath)
+        if response.status_code == 200:
+            com=[]
+            r=response.json()["communityList"]
+            for listt in r:
+                com.append(listt["ndcId"])
+            return com
+        else response.json()
+
     def leave_chat(self, chatId: str):
         """
         Leave an Chat.
